### Description

- What is this PR doing and why?

### Testing

Please select all that apply.

- [ ] Existing unit tests
- [ ] Unit tests added by this PR
- [ ] Other (please explain)
- [ ] This PR is not tested

#### Test instructions

- Please add relevant commands required to reproduce the testing described above
- Please add relevant test outputs (screenshots, logs, etc.)

#### Platforms

Please select all hardware platforms that this PR was tested on.

- [ ] Nvidia GPU
- [ ] AMD GPU
- [ ] Other (please explain)
